@@ -277,7 +277,7 @@ decompose.model <- function(m1,group.by=group.by,include.int="yes",model.type="O
   
   if(model.type=="OLS"){
     # Start OLS Code
-    B <- solve(t(X) %*% X) %*% t(X) %*% diag(as.numeric(m1$model[,1])) 
+    B <- solve(t(X) %*% X) %*% t(X) %*% diag(as.numeric(m1$fitted.values)) 
     ttab <- aggregate(t(B),by=list(group.by),FUN="sum")
     ttab2 <- t(ttab[,-1])
     colnames(ttab2) <- ttab[,1]
